.. _DevelopingFileImporters:

Developing File Importers
-------------------------

We're excited for you to do this, but we haven't documented it yet!

`Come chat with us on Discord <http://steamship.com/discord>`_
